@@ -1,6 +1,5 @@
 import os
 import json
-import atexit
 import aiofiles
 from typing import Optional
 from storages.async_storages.base_nosql_storage import BaseNoSQLStorage
@@ -20,8 +19,6 @@ class JSONStorage(BaseNoSQLStorage):
         self.file_path = file_path if file_path is not None else "./.storages/data.json"
         create_dir(self.file_path)
 
-        atexit.register(self.dump)
-
     @classmethod
     async def create(cls, file_path: Optional[str]):
         obj = cls(file_path)
